#include "tesplashscreen.h"

TeSplashScreen::TeSplashScreen(const QPixmap& thePixmap)
    : QFrame(0, Qt::FramelessWindowHint|Qt::WindowStaysOnTopHint)
    , sPixmap(thePixmap)
{
    setAttribute(Qt::WA_TranslucentBackground);
    setFixedSize(sPixmap.size());
};

void TeSplashScreen::clearMessage()
{
    sMessage.clear();
    repaint();
}

void TeSplashScreen::showMessage(const QString& theMessage, int theAlignment, const QColor& theColor)
{
    sMessage  = theMessage;
    sAlignment = theAlignment;
    sColor  = theColor;
    repaint();
}

void TeSplashScreen::paintEvent(QPaintEvent* pe)
{
    QRect aTextRect(rect());
    aTextRect.setRect(aTextRect.x()+5, aTextRect.y()+5, aTextRect.width()-10, aTextRect.height()-10);

    QPainter aPainter(this);
    aPainter.drawPixmap(rect(), sPixmap);
    aPainter.setPen(sColor);
    aPainter.drawText(aTextRect, sAlignment, sMessage);
}

void TeSplashScreen::showSplash(int delay, QStringList messages, int alignment, const QColor& color)
{
    class SleeperThread : public QThread
    {
    public:
        static void msleep(unsigned long msecs) {QThread::msleep(msecs);}
    };

    TeSplashScreen* aSplashScreen = new TeSplashScreen(sPixmap);
    aSplashScreen->show();

    for(int i=0; i<messages.count();++i)
    {
        aSplashScreen->showMessage(messages[i], alignment, color);
        SleeperThread::msleep(delay);
    }

    delete aSplashScreen;
}

void TeSplashScreen::showSplash(QList<int> delaies, int defaultDelay, QStringList messages, int alignment, const QColor& color)
{
    class SleeperThread : public QThread
    {
    public:
        static void msleep(unsigned long msecs) {QThread::msleep(msecs);}
    };

    TeSplashScreen* aSplashScreen = new TeSplashScreen(sPixmap);
    aSplashScreen->show();

    for(int i=0; i<messages.count();++i)
    {
        aSplashScreen->showMessage(messages[i], alignment, color);
        if(i<delaies.count())
            SleeperThread::msleep(delaies[i]);
        else
            SleeperThread::msleep(defaultDelay);
    }

    delete aSplashScreen;
}
